#################################
Exact k-Medoids Functionality
#################################

.. |br| raw:: html

   <br />

Descriptions of the basic functions are given below.

**Function descriptions:**

.. automodule:: k_medoids_exact
   :members:
   :member-order: bysource
